asdf_prior_jags_out: Example data: asdf prior jags out

asdf_prior_jags_outR Documentation

Example data: asdf prior jags out

Description

A simple model, equivalent to that produced by the output produced by ⁠\link{skeleton}⁠, with the addition of prior samples for all parameters.

Usage

asdf_prior_jags_out

Format

An object of class jagsUI of length 24.


jagshelper documentation built on July 30, 2026, 1:07 a.m.