- df
Primary input can be specified in a number of ways: either a list() of posterior data.frames or matrices,
a list of output objects returned from jagsUI::jags(), a 3-dimensional array in which the input matrices to plot
are separated according to the 3rd array dimension, or a single output object returned from jagsUI::jags() with multiple
arguments passed to p, following.
- p
Parameter name, if input to df is a list of jagsUI output objects; or a vector of parameter names, if
input to df is a single jagsUI output object.
- x
Optional vector of X-coordinates for plotting.
- row
Row to subset, in the case of a 2-d matrix of parameter nodes in-model.
- column
Column to subset, in the case of a 2-d matrix of parameter nodes in-model.
- median
Whether to include median line
- ci
Vector of intervals to overlay. Defaults to 50 percent and 95 percent.
- col
Vector of colors for plotting
- add
Whether to add to existing plot
- dark
Opacity (0-1) for envelopes. Note that multiple overlapping intervals will darken the envelope. Defaults to 0.3.
- outline
Whether to just envelope outlines
- xlab
X-axis label
- ylab
Y-axis label
- main
Plot title. If the default (NULL) is accepted and argument p= is used, p will be used for the title.
- ylim
Y-axis limits for plotting. If the default (NULL) is accepted, these will be determined automatically.
- legend
Whether to automatically try to add a legend. Defaults to TRUE.
- legendnames
Optional vector of names for a legend.
- legendpos
Position for optional legend. Defaults to "topleft".
- transform
Should the y-axis be (back)transformed? Options are "exp",
indicating exponential, or "expit", indicating inverse-logit. Defaults to
"none", indicating no transformation. Note: if transform="exp"is used, consider
adding additional plotting argument log="y".
- ...
additional plotting arguments or arguments to lines()